@@ -1,10 +1,10 @@
-__version__ = "0.1.7"
+__version__ = "0.1.8"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "wiggin15@yahoo.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '03f331c6d11b8836c5616ea5a6332a7923bcff15'
-__git_head_subject__ = 'empty commit after version v0.1.6'
+__git_head_hash__ = 'e491de4dd09c04ba59251b1484dc4c0d03fec8b5'
+__git_head_subject__ = 'Finished release v0.1.8.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
